@@ -220,6 +220,38 @@ gboolean bacon_video_widget_get_auto_resize	 (BaconVideoWidget *bvw);
 void bacon_video_widget_set_auto_resize		 (BaconVideoWidget *bvw,
 						  gboolean auto_resize);
 
+/**
+ * BvwConnectionSpeed:
+ * @BVW_SPEED_14_4_MODEM: 14.4 Kbps Modem
+ * @BVW_SPEED_19_2_MODEM: 19.2 Kbps Modem
+ * @BVW_SPEED_28_8_MODEM: 28.8 Kbps Modem
+ * @BVW_SPEED_33_6_MODEM: 33.6 Kbps Modem
+ * @BVW_SPEED_34_4_MODEM: 34.4 Kbps Modem
+ * @BVW_SPEED_56_ISDN: 56 Kbps Modem/ISDN
+ * @BVW_SPEED_112_ISDN: 112 Kbps Dual ISDN/DSL
+ * @BVW_SPEED_256_DSL: 256 Kbps DSL/Cable
+ * @BVW_SPEED_384_DSL: 384 Kbps DSL/Cable
+ * @BVW_SPEED_512_DSL: 512 Kbps DSL/Cable
+ * @BVW_SPEED_1500_T1: 1.5 Mbps T1/Intranet/LAN
+ * @BVW_SPEED_LAN: Intranet/LAN
+ *
+ * The different connection speeds understood by bacon_video_widget_set_connection_speed().
+ */
+typedef enum {
+	BVW_SPEED_14_4_MODEM = 0,
+	BVW_SPEED_19_2_MODEM,
+	BVW_SPEED_28_8_MODEM,
+	BVW_SPEED_33_6_MODEM,
+	BVW_SPEED_34_4_MODEM,
+	BVW_SPEED_56_ISDN,
+	BVW_SPEED_112_ISDN,
+	BVW_SPEED_256_DSL,
+	BVW_SPEED_384_DSL,
+	BVW_SPEED_512_DSL,
+	BVW_SPEED_1500_T1,
+	BVW_SPEED_LAN
+} BvwConnectionSpeed;
+
 void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
@@ -295,31 +327,29 @@ void bacon_video_widget_get_metadata		 (BaconVideoWidget *bvw,
 
 /* Visualisation functions */
 /**
- * BvwVisualsQuality:
- * @VISUAL_SMALL: small size (240×15)
- * @VISUAL_NORMAL: normal size (320×25)
- * @VISUAL_LARGE: large size (480×25)
- * @VISUAL_EXTRA_LARGE: extra large size (600×30)
- * @NUM_VISUAL_QUALITIES: the number of visual qualities available
+ * BvwVisualizationQuality:
+ * @BVW_VISUALIZATION_SMALL: small size (240×15)
+ * @BVW_VISUALIZATION_NORMAL: normal size (320×25)
+ * @BVW_VISUALIZATION_LARGE: large size (480×25)
+ * @BVW_VISUALIZATION_EXTRA_LARGE: extra large size (600×30)
  *
  * The different visualisation sizes or qualities available for use
- * with bacon_video_widget_set_visuals_quality().
+ * with bacon_video_widget_set_visualization_quality().
  **/
 typedef enum {
-	VISUAL_SMALL = 0,
-	VISUAL_NORMAL,
-	VISUAL_LARGE,
-	VISUAL_EXTRA_LARGE,
-	NUM_VISUAL_QUALITIES
-} BvwVisualsQuality;
+	BVW_VISUALIZATION_SMALL = 0,
+	BVW_VISUALIZATION_NORMAL,
+	BVW_VISUALIZATION_LARGE,
+	BVW_VISUALIZATION_EXTRA_LARGE
+} BvwVisualizationQuality;
 
-void bacon_video_widget_set_show_visuals	  (BaconVideoWidget *bvw,
-						   gboolean show_visuals);
-GList *bacon_video_widget_get_visuals_list	  (BaconVideoWidget *bvw);
-gboolean bacon_video_widget_set_visuals		  (BaconVideoWidget *bvw,
+void bacon_video_widget_set_show_visualizations	  (BaconVideoWidget *bvw,
+						   gboolean show_visualizations);
+GList *bacon_video_widget_get_visualization_list  (BaconVideoWidget *bvw);
+void bacon_video_widget_set_visualization	  (BaconVideoWidget *bvw,
 						   const char *name);
-void bacon_video_widget_set_visuals_quality	  (BaconVideoWidget *bvw,
-						   BvwVisualsQuality quality);
+void bacon_video_widget_set_visualization_quality (BaconVideoWidget *bvw,
+						   BvwVisualizationQuality quality);
 
 /* Picture settings */
 /**
@@ -469,7 +499,7 @@ typedef enum {
 
 BvwAudioOutType bacon_video_widget_get_audio_out_type
 						 (BaconVideoWidget *bvw);
-gboolean bacon_video_widget_set_audio_out_type   (BaconVideoWidget *bvw,
+void bacon_video_widget_set_audio_out_type       (BaconVideoWidget *bvw,
 						  BvwAudioOutType type);
 
 G_END_DECLS
